**********************************
The sherpa.models.parameter module
**********************************

.. currentmodule:: sherpa.models.parameter

.. automodule:: sherpa.models.parameter

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      Parameter
      CompositeParameter
      BinaryOpParameter
      ConstantParameter
      UnaryOpParameter
   
Class Inheritance Diagram
=========================

.. inheritance-diagram:: Parameter CompositeParameter BinaryOpParameter ConstantParameter UnaryOpParameter
   :parts: 1
   
